@@ -1,7 +1,6 @@
 package main
 
 import (
-	"context"
 	"errors"
 	"fmt"
 	"io"
@@ -15,16 +14,14 @@ import (
 	"github.com/lima-vm/lima/cmd/limactl/editflags"
 	"github.com/lima-vm/lima/cmd/limactl/guessarg"
 	"github.com/lima-vm/lima/pkg/editutil"
+	"github.com/lima-vm/lima/pkg/instance"
 	"github.com/lima-vm/lima/pkg/ioutilx"
 	"github.com/lima-vm/lima/pkg/limayaml"
 	networks "github.com/lima-vm/lima/pkg/networks/reconcile"
-	"github.com/lima-vm/lima/pkg/osutil"
-	"github.com/lima-vm/lima/pkg/start"
 	"github.com/lima-vm/lima/pkg/store"
 	"github.com/lima-vm/lima/pkg/store/filenames"
 	"github.com/lima-vm/lima/pkg/templatestore"
 	"github.com/lima-vm/lima/pkg/uiutil"
-	"github.com/lima-vm/lima/pkg/version"
 	"github.com/lima-vm/lima/pkg/yqutil"
 	"github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
@@ -98,7 +95,7 @@ See the examples in 'limactl create --help'.
 	if runtime.GOOS != "windows" {
 		startCommand.Flags().Bool("foreground", false, "run the hostagent in the foreground")
 	}
-	startCommand.Flags().Duration("timeout", start.DefaultWatchHostAgentEventsTimeout, "duration to wait for the instance to be running before timing out")
+	startCommand.Flags().Duration("timeout", instance.DefaultWatchHostAgentEventsTimeout, "duration to wait for the instance to be running before timing out")
 	return startCommand
 }
 
@@ -128,9 +125,11 @@ func loadOrCreateInstance(cmd *cobra.Command, args []string, createOnly bool) (*
 
 	const yBytesLimit = 4 * 1024 * 1024 // 4MiB
 
-	if ok, u := guessarg.SeemsTemplateURL(arg); ok {
+	isTemplateURL, templateURL := guessarg.SeemsTemplateURL(arg)
+	switch {
+	case isTemplateURL:
 		// No need to use SecureJoin here. https://github.com/lima-vm/lima/pull/805#discussion_r853411702
-		templateName := filepath.Join(u.Host, u.Path)
+		templateName := filepath.Join(templateURL.Host, templateURL.Path)
 		logrus.Debugf("interpreting argument %q as a template name %q", arg, templateName)
 		if st.instName == "" {
 			// e.g., templateName = "deprecated/centos-7" , st.instName = "centos-7"
@@ -140,7 +139,7 @@ func loadOrCreateInstance(cmd *cobra.Command, args []string, createOnly bool) (*
 		if err != nil {
 			return nil, err
 		}
-	} else if guessarg.SeemsHTTPURL(arg) {
+	case guessarg.SeemsHTTPURL(arg):
 		if st.instName == "" {
 			st.instName, err = guessarg.InstNameFromURL(arg)
 			if err != nil {
@@ -161,7 +160,7 @@ func loadOrCreateInstance(cmd *cobra.Command, args []string, createOnly bool) (*
 		if err != nil {
 			return nil, err
 		}
-	} else if guessarg.SeemsFileURL(arg) {
+	case guessarg.SeemsFileURL(arg):
 		if st.instName == "" {
 			st.instName, err = guessarg.InstNameFromURL(arg)
 			if err != nil {
@@ -178,7 +177,7 @@ func loadOrCreateInstance(cmd *cobra.Command, args []string, createOnly bool) (*
 		if err != nil {
 			return nil, err
 		}
-	} else if guessarg.SeemsYAMLPath(arg) {
+	case guessarg.SeemsYAMLPath(arg):
 		if st.instName == "" {
 			st.instName, err = guessarg.InstNameFromYAMLPath(arg)
 			if err != nil {
@@ -195,7 +194,7 @@ func loadOrCreateInstance(cmd *cobra.Command, args []string, createOnly bool) (*
 		if err != nil {
 			return nil, err
 		}
-	} else if arg == "-" {
+	case arg == "-":
 		if st.instName == "" {
 			return nil, errors.New("must pass instance name with --name when reading template from stdin")
 		}
@@ -209,7 +208,7 @@ func loadOrCreateInstance(cmd *cobra.Command, args []string, createOnly bool) (*
 			return nil, errors.New("cannot use --tty=true and read template from stdin together")
 		}
 		tty = false
-	} else {
+	default:
 		if arg == "" {
 			if st.instName == "" {
 				st.instName = DefaultInstanceName
@@ -227,7 +226,7 @@ func loadOrCreateInstance(cmd *cobra.Command, args []string, createOnly bool) (*
 		inst, err := store.Inspect(st.instName)
 		if err == nil {
 			if createOnly {
-				return nil, fmt.Errorf("Instance %q already exists", st.instName)
+				return nil, fmt.Errorf("instance %q already exists", st.instName)
 			}
 			logrus.Infof("Using the existing instance %q", st.instName)
 			yqExprs, err := editflags.YQExpressions(flags, false)
@@ -274,8 +273,8 @@ func loadOrCreateInstance(cmd *cobra.Command, args []string, createOnly bool) (*
 			return nil, err
 		}
 	}
-	saveBrokenEditorBuffer := tty
-	return createInstance(cmd.Context(), st, saveBrokenEditorBuffer)
+	saveBrokenYAML := tty
+	return instance.Create(cmd.Context(), st.instName, st.yBytes, saveBrokenYAML)
 }
 
 func applyYQExpressionToExistingInstance(inst *store.Instance, yq string) (*store.Instance, error) {
@@ -292,6 +291,18 @@ func applyYQExpressionToExistingInstance(inst *store.Instance, yq string) (*stor
 	if err != nil {
 		return nil, err
 	}
+	y, err := limayaml.Load(yBytes, filePath)
+	if err != nil {
+		return nil, err
+	}
+	if err := limayaml.Validate(y, true); err != nil {
+		rejectedYAML := "lima.REJECTED.yaml"
+		if writeErr := os.WriteFile(rejectedYAML, yBytes, 0o644); writeErr != nil {
+			return nil, fmt.Errorf("the YAML is invalid, attempted to save the buffer as %q but failed: %w: %w", rejectedYAML, writeErr, err)
+		}
+		// TODO: may need to support editing the rejected YAML
+		return nil, fmt.Errorf("the YAML is invalid, saved the buffer as %q: %w", rejectedYAML, err)
+	}
 	if err := os.WriteFile(filePath, yBytes, 0o644); err != nil {
 		return nil, err
 	}
@@ -299,66 +310,6 @@ func applyYQExpressionToExistingInstance(inst *store.Instance, yq string) (*stor
 	return store.Inspect(inst.Name)
 }
 
-func createInstance(ctx context.Context, st *creatorState, saveBrokenEditorBuffer bool) (*store.Instance, error) {
-	if st.instName == "" {
-		return nil, errors.New("got empty st.instName")
-	}
-	if len(st.yBytes) == 0 {
-		return nil, errors.New("got empty st.yBytes")
-	}
-
-	instDir, err := store.InstanceDir(st.instName)
-	if err != nil {
-		return nil, err
-	}
-
-	// the full path of the socket name must be less than UNIX_PATH_MAX chars.
-	maxSockName := filepath.Join(instDir, filenames.LongestSock)
-	if len(maxSockName) >= osutil.UnixPathMax {
-		return nil, fmt.Errorf("instance name %q too long: %q must be less than UNIX_PATH_MAX=%d characters, but is %d",
-			st.instName, maxSockName, osutil.UnixPathMax, len(maxSockName))
-	}
-	if _, err := os.Stat(instDir); !errors.Is(err, os.ErrNotExist) {
-		return nil, fmt.Errorf("instance %q already exists (%q)", st.instName, instDir)
-	}
-	// limayaml.Load() needs to pass the store file path to limayaml.FillDefault() to calculate default MAC addresses
-	filePath := filepath.Join(instDir, filenames.LimaYAML)
-	y, err := limayaml.Load(st.yBytes, filePath)
-	if err != nil {
-		return nil, err
-	}
-	if err := limayaml.Validate(*y, true); err != nil {
-		if !saveBrokenEditorBuffer {
-			return nil, err
-		}
-		rejectedYAML := "lima.REJECTED.yaml"
-		if writeErr := os.WriteFile(rejectedYAML, st.yBytes, 0o644); writeErr != nil {
-			return nil, fmt.Errorf("the YAML is invalid, attempted to save the buffer as %q but failed: %w: %w", rejectedYAML, writeErr, err)
-		}
-		return nil, fmt.Errorf("the YAML is invalid, saved the buffer as %q: %w", rejectedYAML, err)
-	}
-	if err := os.MkdirAll(instDir, 0o700); err != nil {
-		return nil, err
-	}
-	if err := os.WriteFile(filePath, st.yBytes, 0o644); err != nil {
-		return nil, err
-	}
-	if err := os.WriteFile(filepath.Join(instDir, filenames.LimaVersion), []byte(version.Version), 0o444); err != nil {
-		return nil, err
-	}
-
-	inst, err := store.Inspect(st.instName)
-	if err != nil {
-		return nil, err
-	}
-
-	if err := start.Register(ctx, inst); err != nil {
-		return nil, err
-	}
-
-	return inst, nil
-}
-
 type creatorState struct {
 	instName string // instance name
 	yBytes   []byte // yaml bytes
@@ -373,6 +324,21 @@ func modifyInPlace(st *creatorState, yq string) error {
 	return nil
 }
 
+// exitSuccessError is an error that indicates a successful exit.
+type exitSuccessError struct {
+	Msg string
+}
+
+// Error implements error.
+func (e exitSuccessError) Error() string {
+	return e.Msg
+}
+
+// ExitCode implements ExitCoder.
+func (exitSuccessError) ExitCode() int {
+	return 0
+}
+
 func chooseNextCreatorState(st *creatorState, yq string) (*creatorState, error) {
 	for {
 		if err := modifyInPlace(st, yq); err != nil {
@@ -411,9 +377,9 @@ func chooseNextCreatorState(st *creatorState, yq string) (*creatorState, error)
 				return st, err
 			}
 			if len(st.yBytes) == 0 {
-				logrus.Info("Aborting, as requested by saving the file with empty content")
-				os.Exit(0)
-				return st, errors.New("should not reach here")
+				const msg = "Aborting, as requested by saving the file with empty content"
+				logrus.Info(msg)
+				return nil, exitSuccessError{Msg: msg}
 			}
 			return st, nil
 		case 2: // "Choose another template..."
@@ -446,8 +412,7 @@ func chooseNextCreatorState(st *creatorState, yq string) (*creatorState, error)
 			}
 			continue
 		case 3: // "Exit"
-			os.Exit(0)
-			return st, errors.New("should not reach here")
+			return nil, exitSuccessError{Msg: "Choosing to exit"}
 		default:
 			return st, fmt.Errorf("unexpected answer %q", ans)
 		}
@@ -483,7 +448,7 @@ func createAction(cmd *cobra.Command, args []string) error {
 	if len(inst.Errors) > 0 {
 		return fmt.Errorf("errors inspecting instance: %+v", inst.Errors)
 	}
-	if _, err = start.Prepare(cmd.Context(), inst); err != nil {
+	if _, err = instance.Prepare(cmd.Context(), inst); err != nil {
 		return err
 	}
 	logrus.Infof("Run `limactl start %s` to start the instance.", inst.Name)
@@ -506,7 +471,7 @@ func startAction(cmd *cobra.Command, args []string) error {
 	switch inst.Status {
 	case store.StatusRunning:
 		logrus.Infof("The instance %q is already running. Run `%s` to open the shell.",
-			inst.Name, start.LimactlShellCmd(inst.Name))
+			inst.Name, instance.LimactlShellCmd(inst.Name))
 		// Not an error
 		return nil
 	case store.StatusStopped:
@@ -533,10 +498,10 @@ func startAction(cmd *cobra.Command, args []string) error {
 		return err
 	}
 	if timeout > 0 {
-		ctx = start.WithWatchHostAgentTimeout(ctx, timeout)
+		ctx = instance.WithWatchHostAgentTimeout(ctx, timeout)
 	}
 
-	return start.Start(ctx, inst, launchHostAgentForeground)
+	return instance.Start(ctx, inst, launchHostAgentForeground)
 }
 
 func createBashComplete(cmd *cobra.Command, _ []string, _ string) ([]string, cobra.ShellCompDirective) {
