@@ -35,6 +35,7 @@ declare -A CHECKS=(
 	["disk"]=""
 	["user-v2"]=""
 	["mount-path-with-spaces"]=""
+	["provision-ansible"]=""
 )
 
 case "$NAME" in
@@ -62,6 +63,7 @@ case "$NAME" in
 	CHECKS["snapshot-online"]="1"
 	CHECKS["snapshot-offline"]="1"
 	CHECKS["mount-path-with-spaces"]="1"
+	CHECKS["provision-ansible"]="1"
 	;;
 "net-user-v2")
 	CHECKS["port-forwards"]=""
@@ -95,7 +97,9 @@ function diagnose() {
 	tail "$HOME/.lima/${NAME}"/*.log
 	limactl shell "$NAME" systemctl --no-pager status
 	limactl shell "$NAME" systemctl --no-pager
-	limactl shell "$NAME" sudo cat /var/log/cloud-init-output.log
+	mkdir -p failure-logs
+	cp -pf "$HOME/.lima/${NAME}"/*.log failure-logs/
+	limactl shell "$NAME" sudo cat /var/log/cloud-init-output.log | tee failure-logs/cloud-init-output.log
 	set +x -e
 }
 
@@ -143,6 +147,11 @@ if [[ -n ${CHECKS["mount-path-with-spaces"]} ]]; then
 	[ "$(limactl shell "$NAME" cat "/tmp/lima test dir with spaces/test file")" = "test file content" ]
 fi
 
+if [[ -n ${CHECKS["provision-ansible"]} ]]; then
+	INFO 'Testing that /tmp/ansible was created successfully on provision'
+	limactl shell "$NAME" test -e /tmp/ansible
+fi
+
 INFO "Testing proxy settings are imported"
 got=$(limactl shell "$NAME" env | grep FTP_PROXY)
 # Expected: FTP_PROXY is set in addition to ftp_proxy, localhost is replaced
@@ -325,7 +334,11 @@ if [[ -n ${CHECKS["restart"]} ]]; then
 
 	export ftp_proxy=my.proxy:8021
 	INFO "Restarting \"$NAME\""
-	limactl start "$NAME"
+	if ! limactl start "$NAME"; then
+		ERROR "Failed to start \"$NAME\""
+		diagnose "$NAME"
+		exit 1
+	fi
 
 	INFO "Make sure proxy setting is updated"
 	got=$(limactl shell "$NAME" env | grep FTP_PROXY)
@@ -358,7 +371,11 @@ if [[ -n ${CHECKS["user-v2"]} ]]; then
 	INFO "Testing user-v2 network"
 	secondvm="$NAME-1"
 	"${LIMACTL_CREATE[@]}" "$FILE" --name "$secondvm"
-	limactl start "$secondvm"
+	if ! limactl start "$secondvm"; then
+		ERROR "Failed to start \"$secondvm\""
+		diagnose "$secondvm"
+		exit 1
+	fi
 	secondvmDNS="lima-$secondvm.internal"
 	INFO "DNS of $secondvm is $secondvmDNS"
 	set -x
