@@ -19,6 +19,11 @@ for REPO in main community; do
 	fi
 done
 
+# Alpine comes with doas instead of sudo
+if ! command -v sudo >/dev/null 2>&1; then
+	apk add sudo
+fi
+
 # Alpine doesn't use PAM so we need to explicitly allow public key auth
 usermod -p '*' "${LIMA_CIDATA_USER}"
 
