@@ -1,6 +1,7 @@
 package cidata
 
 import (
+	"compress/gzip"
 	"errors"
 	"fmt"
 	"io"
@@ -9,6 +10,7 @@ import (
 	"os"
 	"path"
 	"path/filepath"
+	"slices"
 	"strconv"
 	"strings"
 	"time"
@@ -24,7 +26,6 @@ import (
 	"github.com/lima-vm/lima/pkg/store/filenames"
 	"github.com/lima-vm/lima/pkg/usrlocalsharelima"
 	"github.com/sirupsen/logrus"
-	"golang.org/x/exp/slices"
 )
 
 var netLookupIP = func(host string) []net.IP {
@@ -111,7 +112,7 @@ func setupEnv(y *limayaml.LimaYAML, args TemplateArgs) (map[string]string, error
 }
 
 func GenerateISO9660(instDir, name string, y *limayaml.LimaYAML, udpDNSLocalPort, tcpDNSLocalPort int, nerdctlArchive string, vsockPort int, virtioPort string) error {
-	if err := limayaml.Validate(*y, false); err != nil {
+	if err := limayaml.Validate(y, false); err != nil {
 		return err
 	}
 	u, err := osutil.LimaUser(true)
@@ -269,17 +270,18 @@ func GenerateISO9660(instDir, name string, y *limayaml.LimaYAML, udpDNSLocalPort
 		return err
 	}
 
-	if len(y.DNS) > 0 {
+	switch {
+	case len(y.DNS) > 0:
 		for _, addr := range y.DNS {
 			args.DNSAddresses = append(args.DNSAddresses, addr.String())
 		}
-	} else if firstUsernetIndex != -1 || *y.VMType == limayaml.VZ {
+	case firstUsernetIndex != -1 || *y.VMType == limayaml.VZ:
 		args.DNSAddresses = append(args.DNSAddresses, args.SlirpDNS)
-	} else if *y.HostResolver.Enabled {
+	case *y.HostResolver.Enabled:
 		args.UDPDNSLocalPort = udpDNSLocalPort
 		args.TCPDNSLocalPort = tcpDNSLocalPort
 		args.DNSAddresses = append(args.DNSAddresses, args.SlirpDNS)
-	} else {
+	default:
 		args.DNSAddresses, err = osutil.DNSAddresses()
 		if err != nil {
 			return err
@@ -334,19 +336,37 @@ func GenerateISO9660(instDir, name string, y *limayaml.LimaYAML, udpDNSLocalPort
 			})
 		case limayaml.ProvisionModeBoot:
 			continue
+		case limayaml.ProvisionModeAnsible:
+			continue
 		default:
 			return fmt.Errorf("unknown provision mode %q", f.Mode)
 		}
 	}
 
-	guestAgentBinary, err := GuestAgentBinary(*y.OS, *y.Arch)
+	guestAgentBinary, err := usrlocalsharelima.GuestAgentBinary(*y.OS, *y.Arch)
 	if err != nil {
 		return err
 	}
-	defer guestAgentBinary.Close()
+	var guestAgent io.ReadCloser
+	guestAgent, err = os.Open(guestAgentBinary)
+	if err != nil {
+		if !errors.Is(err, os.ErrNotExist) {
+			return err
+		}
+		compressedGuestAgent, err := os.Open(guestAgentBinary + ".gz")
+		if err != nil {
+			return err
+		}
+		logrus.Debugf("Decompressing %s.gz", guestAgentBinary)
+		guestAgent, err = gzip.NewReader(compressedGuestAgent)
+		if err != nil {
+			return err
+		}
+	}
+	defer guestAgent.Close()
 	layout = append(layout, iso9660util.Entry{
 		Path:   "lima-guestagent",
-		Reader: guestAgentBinary,
+		Reader: guestAgent,
 	})
 
 	if nerdctlArchive != "" {
@@ -373,21 +393,6 @@ func GenerateISO9660(instDir, name string, y *limayaml.LimaYAML, udpDNSLocalPort
 	return iso9660util.Write(filepath.Join(instDir, filenames.CIDataISO), "cidata", layout)
 }
 
-func GuestAgentBinary(ostype limayaml.OS, arch limayaml.Arch) (io.ReadCloser, error) {
-	if ostype == "" {
-		return nil, errors.New("os must be set")
-	}
-	if arch == "" {
-		return nil, errors.New("arch must be set")
-	}
-	dir, err := usrlocalsharelima.Dir()
-	if err != nil {
-		return nil, err
-	}
-	gaPath := filepath.Join(dir, "lima-guestagent."+ostype+"-"+arch)
-	return os.Open(gaPath)
-}
-
 func getCert(content string) Cert {
 	lines := []string{}
 	for _, line := range strings.Split(content, "\n") {
