@@ -7,9 +7,9 @@ import (
 	"testing"
 
 	"github.com/lima-vm/lima/pkg/networks"
+	"github.com/lima-vm/lima/pkg/ptr"
 
 	"github.com/lima-vm/lima/pkg/limayaml"
-	"github.com/xorcare/pointer"
 	"gotest.tools/v3/assert"
 )
 
@@ -21,10 +21,7 @@ func TestSetupEnv(t *testing.T) {
 	netLookupIP = fakeLookupIP
 	urlMustParse := func(urlStr string) *url.URL {
 		u, err := url.Parse(urlStr)
-		if err != nil {
-			panic(err)
-		}
-
+		assert.NilError(t, err)
 		return u
 	}
 
@@ -49,7 +46,7 @@ func TestSetupEnv(t *testing.T) {
 			envKey := "http_proxy"
 			envValue := httpProxy.String()
 			templateArgs := TemplateArgs{SlirpGateway: networks.SlirpGateway}
-			envs, err := setupEnv(&limayaml.LimaYAML{PropagateProxyEnv: pointer.Bool(false), Env: map[string]string{envKey: envValue}}, templateArgs)
+			envs, err := setupEnv(&limayaml.LimaYAML{PropagateProxyEnv: ptr.Of(false), Env: map[string]string{envKey: envValue}}, templateArgs)
 			assert.NilError(t, err)
 			assert.Equal(t, envs[envKey], strings.ReplaceAll(envValue, httpProxy.Hostname(), networks.SlirpGateway))
 		})
@@ -60,7 +57,7 @@ func TestSetupInvalidEnv(t *testing.T) {
 	envKey := "http_proxy"
 	envValue := "://localhost:8080"
 	templateArgs := TemplateArgs{SlirpGateway: networks.SlirpGateway}
-	envs, err := setupEnv(&limayaml.LimaYAML{PropagateProxyEnv: pointer.Bool(false), Env: map[string]string{envKey: envValue}}, templateArgs)
+	envs, err := setupEnv(&limayaml.LimaYAML{PropagateProxyEnv: ptr.Of(false), Env: map[string]string{envKey: envValue}}, templateArgs)
 	assert.NilError(t, err)
 	assert.Equal(t, envs[envKey], envValue)
 }
