@@ -6,6 +6,7 @@ import (
 
 	"github.com/lima-vm/lima/pkg/guestagent/api"
 	"google.golang.org/grpc"
+	"google.golang.org/grpc/resolver"
 	"google.golang.org/protobuf/types/known/emptypb"
 )
 
@@ -15,13 +16,14 @@ type GuestAgentClient struct {
 
 func NewGuestAgentClient(dialFn func(ctx context.Context) (net.Conn, error)) (*GuestAgentClient, error) {
 	opts := []grpc.DialOption{
-		grpc.WithContextDialer(func(ctx context.Context, target string) (net.Conn, error) {
+		grpc.WithContextDialer(func(ctx context.Context, _ string) (net.Conn, error) {
 			return dialFn(ctx)
 		}),
 		grpc.WithTransportCredentials(NewCredentials()),
 	}
 
-	clientConn, err := grpc.Dial("", opts...)
+	resolver.SetDefaultScheme("passthrough")
+	clientConn, err := grpc.NewClient("", opts...)
 	if err != nil {
 		return nil, err
 	}
