@@ -34,6 +34,7 @@ type LimaYAML struct {
 	Networks           []Network     `yaml:"networks,omitempty" json:"networks,omitempty"`
 	// `network` was deprecated in Lima v0.7.0, removed in Lima v0.14.0. Use `networks` instead.
 	Env          map[string]string `yaml:"env,omitempty" json:"env,omitempty"`
+	Param        map[string]string `yaml:"param,omitempty" json:"param,omitempty"`
 	DNS          []net.IP          `yaml:"dns,omitempty" json:"dns,omitempty"`
 	HostResolver HostResolver      `yaml:"hostResolver,omitempty" json:"hostResolver,omitempty"`
 	// `useHostResolver` was deprecated in Lima v0.8.1, removed in Lima v0.14.0. Use `hostResolver.enabled` instead.
@@ -72,8 +73,8 @@ const (
 )
 
 type Rosetta struct {
-	Enabled *bool `yaml:"enabled" json:"enabled"`
-	BinFmt  *bool `yaml:"binfmt" json:"binfmt"`
+	Enabled *bool `yaml:"enabled,omitempty" json:"enabled,omitempty"`
+	BinFmt  *bool `yaml:"binfmt,omitempty" json:"binfmt,omitempty"`
 }
 
 type File struct {
@@ -180,12 +181,14 @@ const (
 	ProvisionModeUser       ProvisionMode = "user"
 	ProvisionModeBoot       ProvisionMode = "boot"
 	ProvisionModeDependency ProvisionMode = "dependency"
+	ProvisionModeAnsible    ProvisionMode = "ansible"
 )
 
 type Provision struct {
 	Mode                            ProvisionMode `yaml:"mode" json:"mode"` // default: "system"
 	SkipDefaultDependencyResolution *bool         `yaml:"skipDefaultDependencyResolution,omitempty" json:"skipDefaultDependencyResolution,omitempty"`
 	Script                          string        `yaml:"script" json:"script"`
+	Playbook                        string        `yaml:"playbook,omitempty" json:"playbook,omitempty"`
 }
 
 type Containerd struct {
