@@ -33,7 +33,7 @@ func Sudoers() (string, error) {
 	for _, name := range names {
 		sb.WriteRune('\n')
 		sb.WriteString(fmt.Sprintf("# Manage %q network daemons\n", name))
-		for _, daemon := range []string{VDESwitch, VDEVMNet, SocketVMNet} {
+		for _, daemon := range []string{SocketVMNet} {
 			if ok, err := config.IsDaemonInstalled(daemon); err != nil {
 				return "", err
 			} else if !ok {
@@ -61,7 +61,7 @@ func (config *YAML) passwordLessSudo() error {
 	}
 	// Verify that user/groups for both daemons work without a password, e.g.
 	// %admin ALL = (ALL:ALL) NOPASSWD: ALL
-	for _, daemon := range []string{VDESwitch, VDEVMNet, SocketVMNet} {
+	for _, daemon := range []string{SocketVMNet} {
 		if ok, err := config.IsDaemonInstalled(daemon); err != nil {
 			return err
 		} else if !ok {
