@@ -7,6 +7,7 @@ type SPNetworkDataType struct {
 type NetworkDataType struct {
 	DNS       DNS     `json:"DNS"`
 	Interface string  `json:"interface"`
+	IPv4      IPv4    `json:"IPv4,omitempty"`
 	Proxies   Proxies `json:"Proxies"`
 }
 
@@ -14,6 +15,10 @@ type DNS struct {
 	ServerAddresses []string `json:"ServerAddresses"`
 }
 
+type IPv4 struct {
+	Addresses []string `json:"Addresses,omitempty"`
+}
+
 type Proxies struct {
 	ExceptionList []string    `json:"ExceptionList"` // default: ["*.local", "169.254/16"]
 	FTPEnable     string      `json:"FTPEnable"`
