@@ -124,37 +124,36 @@ func startVM(ctx context.Context, driver *driver.BaseDriver) (*virtualMachineWra
 }
 
 func startUsernet(ctx context.Context, driver *driver.BaseDriver) (*usernet.Client, error) {
-	firstUsernetIndex := limayaml.FirstUsernetIndex(driver.Yaml)
-	if firstUsernetIndex == -1 {
-		// Start a in-process gvisor-tap-vsock
-		endpointSock, err := usernet.SockWithDirectory(driver.Instance.Dir, "", usernet.EndpointSock)
-		if err != nil {
-			return nil, err
-		}
-		vzSock, err := usernet.SockWithDirectory(driver.Instance.Dir, "", usernet.FDSock)
-		if err != nil {
-			return nil, err
-		}
-		os.RemoveAll(endpointSock)
-		os.RemoveAll(vzSock)
-		err = usernet.StartGVisorNetstack(ctx, &usernet.GVisorNetstackOpts{
-			MTU:      1500,
-			Endpoint: endpointSock,
-			FdSocket: vzSock,
-			Async:    true,
-			DefaultLeases: map[string]string{
-				networks.SlirpIPAddress: limayaml.MACAddress(driver.Instance.Dir),
-			},
-			Subnet: networks.SlirpNetwork,
-		})
-		if err != nil {
-			return nil, err
-		}
-		subnetIP, _, err := net.ParseCIDR(networks.SlirpNetwork)
-		return usernet.NewClient(endpointSock, subnetIP), err
+	if firstUsernetIndex := limayaml.FirstUsernetIndex(driver.Yaml); firstUsernetIndex != -1 {
+		nwName := driver.Yaml.Networks[firstUsernetIndex].Lima
+		return usernet.NewClientByName(nwName), nil
 	}
-	nwName := driver.Yaml.Networks[firstUsernetIndex].Lima
-	return usernet.NewClientByName(nwName), nil
+	// Start a in-process gvisor-tap-vsock
+	endpointSock, err := usernet.SockWithDirectory(driver.Instance.Dir, "", usernet.EndpointSock)
+	if err != nil {
+		return nil, err
+	}
+	vzSock, err := usernet.SockWithDirectory(driver.Instance.Dir, "", usernet.FDSock)
+	if err != nil {
+		return nil, err
+	}
+	os.RemoveAll(endpointSock)
+	os.RemoveAll(vzSock)
+	err = usernet.StartGVisorNetstack(ctx, &usernet.GVisorNetstackOpts{
+		MTU:      1500,
+		Endpoint: endpointSock,
+		FdSocket: vzSock,
+		Async:    true,
+		DefaultLeases: map[string]string{
+			networks.SlirpIPAddress: limayaml.MACAddress(driver.Instance.Dir),
+		},
+		Subnet: networks.SlirpNetwork,
+	})
+	if err != nil {
+		return nil, err
+	}
+	subnetIP, _, err := net.ParseCIDR(networks.SlirpNetwork)
+	return usernet.NewClient(endpointSock, subnetIP), err
 }
 
 func createVM(driver *driver.BaseDriver) (*vz.VirtualMachine, error) {
@@ -575,7 +574,8 @@ func attachFolderMounts(driver *driver.BaseDriver, vmConfig *vz.VirtualMachineCo
 }
 
 func attachAudio(driver *driver.BaseDriver, config *vz.VirtualMachineConfiguration) error {
-	if *driver.Yaml.Audio.Device == "vz" {
+	switch *driver.Yaml.Audio.Device {
+	case "vz", "default":
 		outputStream, err := vz.NewVirtioSoundDeviceHostOutputStreamConfiguration()
 		if err != nil {
 			return err
@@ -588,8 +588,12 @@ func attachAudio(driver *driver.BaseDriver, config *vz.VirtualMachineConfigurati
 		config.SetAudioDevicesVirtualMachineConfiguration([]vz.AudioDeviceConfiguration{
 			soundDeviceConfiguration,
 		})
+		return nil
+	case "", "none":
+		return nil
+	default:
+		return fmt.Errorf("unexpected audio device %q", *driver.Yaml.Audio.Device)
 	}
-	return nil
 }
 
 func attachOtherDevices(_ *driver.BaseDriver, vmConfig *vz.VirtualMachineConfiguration) error {
@@ -712,10 +716,10 @@ func createSockPair() (server, client *os.File, _ error) {
 	}
 	server = os.NewFile(uintptr(serverFD), "server")
 	client = os.NewFile(uintptr(clientFD), "client")
-	runtime.SetFinalizer(server, func(file *os.File) {
+	runtime.SetFinalizer(server, func(*os.File) {
 		logrus.Debugf("Server network file GC'ed")
 	})
-	runtime.SetFinalizer(client, func(file *os.File) {
+	runtime.SetFinalizer(client, func(*os.File) {
 		logrus.Debugf("Client network file GC'ed")
 	})
 	vmNetworkFiles = append(vmNetworkFiles, server, client)
